//
//  PDBaseViewController.swift
//  PrinterDemo
//
//  Created by ios on 2019/9/5.
//  Copyright © 2019 XiamenHY. All rights reserved.
//

import UIKit
import Then
import Reusable

class PDBaseViewController: UIViewController {

    override func viewDidLoad() {
        super.viewDidLoad()

        view.backgroundColor = kRGBACOLOR(r: 242, g: 242, b: 242, a: 1)
        configUI()
        
    }
    
    func configUI() {}

    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        configNavigationBar()
    }
    
    func configNavigationBar() {
        guard let navi = navigationController else { return }
        if navi.visibleViewController == self {
            navi.setBarStyle(.theme)
            navi.disablePopGesture = false
            navi.setNavigationBarHidden(false, animated: true)
            if navi.viewControllers.count > 1 {
                navigationItem.leftBarButtonItem = UIBarButtonItem.init(image: UIImage(named: "nav_return_btn"), style: UIBarButtonItem.Style.plain, target: self, action: #selector(pressBack))
            }
        }
    }
    
    @objc func pressBack() {
        navigationController?.popViewController(animated: true)
    }
    
    override func touchesBegan(_ touches: Set<UITouch>, with event: UIEvent?) {
        super.touchesBegan(touches, with: event)
        view.endEditing(true)
    }
}

extension PDBaseViewController {
    
    override var preferredStatusBarStyle: UIStatusBarStyle{
        return .lightContent
    }
}


fileprivate weak var AlertController: UIAlertController?

public extension UIViewController {
    
    func bk_presentAlertController(
        title: String?,
        message: String?,
        preferredStyle: UIAlertController.Style,
        actions: [UIAlertAction])
        -> Void
    {
        DispatchQueue.main.async {
            let closure = { () in
                let temp = UIAlertController.init(title: title, message: message, preferredStyle: preferredStyle)
                for action in actions {
                    temp.addAction(action)
                }
                temp.popoverPresentationController?.sourceView = self.view
                temp.popoverPresentationController?.sourceRect = CGRect.init(x: 0, y: self.view.bounds.height/2, width: self.view.bounds.width, height: 1)
                self.present(temp, animated: true, completion: nil)
                AlertController = temp
            }
            if let alert = AlertController,
                let _ = alert.presentingViewController {
                alert.dismiss(animated: true, completion: closure)
            }else {
                closure()
            }
        }
    }
    
    func bk_presentWarningAlertController(
        title: String,
        message: String,
        style: UIAlertAction.Style,
        closure: ((UIAlertAction) -> Void)? = nil)
        -> Void
    {
        DispatchQueue.main.async {
            let action = UIAlertAction.init(title: "OK".localized, style: style, handler: closure)
            self.bk_presentAlertController(title: title, message: message, preferredStyle: .alert, actions: [action])
        }
    }
    
    func bk_presentDecisionAlertController(
        title: String?,
        message: String?,
        decisionTitle: String?,
        decisionClosure: @escaping (UIAlertAction) -> Void,
        cancelClosure: ((UIAlertAction) -> Void)? = nil)
        -> Void
    {
        DispatchQueue.main.async {
            let action1 = UIAlertAction.init(title: decisionTitle ?? "OK".localized, style: .default, handler: decisionClosure)
            let action2 = UIAlertAction.init(title: "Cancel".localized, style: .cancel, handler: cancelClosure)
            self.bk_presentAlertController(title: title, message: message, preferredStyle: .alert, actions: [action1, action2])
        }
    }
    
    func presentInputAlertController(msg: String, inputDesc: String, closure: @escaping ((String) -> Void)) -> Void {
        
        DispatchQueue.main.async {
            let temp = UIAlertController(title: "Tips".localized, message: msg, preferredStyle: .alert)
            temp.addTextField {
                $0.placeholder = inputDesc
                $0.keyboardType = .numberPad
            }
            let confirm = UIAlertAction(title: "OK".localized, style: .default) { [weak temp] (_) in
                
                guard let textField = temp?.textFields?[0] else { return }
                guard let text = textField.text, !text.isEmpty else { return }
                closure(text)
            }
            let cancel = UIAlertAction(title: "Cancel".localized, style: .cancel, handler: nil)
            temp.addAction(confirm)
            temp.addAction(cancel)
            self.present(temp, animated: true, completion: nil)
        }
    }
    
    func presentSegmentAlertController(title: String, msg: String, items:[Any], handler: @escaping ((Int) -> Void)) {
        
        let temp = UIAlertController(title: title, message: msg, preferredStyle: .alert)
        let segment = UISegmentedControl.init(items: items)
        if #available(iOS 13, *) {
            segment.selectedSegmentTintColor = UIColor.theme
        }else {
            segment.tintColor = UIColor.theme
        }
        segment.setTitleTextAttributes([NSAttributedString.Key.font:UIFont.pingFang(size: 14),NSAttributedString.Key.foregroundColor:UIColor.black], for: UIControl.State.normal)
        segment.setTitleTextAttributes([NSAttributedString.Key.font:UIFont.pingFang(size: 14),NSAttributedString.Key.foregroundColor:UIColor.white], for: UIControl.State.selected)

        temp.view.addSubview(segment)
        segment.snp.makeConstraints {
            $0.centerY.equalToSuperview()
            $0.left.equalTo(22)
            $0.right.equalTo(-22)
        }
        let confirm = UIAlertAction(title: "OK".localized, style: .default) { (_) in
            if segment.selectedSegmentIndex == -1 {
                SVProgressHUD.showError(withStatus: "Not to choose".localized)
                return
            }
            handler(segment.selectedSegmentIndex)
        }
        let cancel = UIAlertAction(title: "Cancel".localized, style: .cancel, handler: nil)
        temp.addAction(confirm)
        temp.addAction(cancel)
        self.present(temp, animated: true, completion: nil)
    }
    
    func presentInputNameAlertController(msg: String, inputDesc: String, closure: @escaping ((String) -> Void)) -> Void {
        
        DispatchQueue.main.async {
            let temp = UIAlertController(title: "Tips".localized, message: msg, preferredStyle: .alert)
            temp.addTextField {
                $0.placeholder = inputDesc
            }
            let confirm = UIAlertAction(title: "OK".localized, style: .default) { [weak temp] (_) in
                
                guard let textField = temp?.textFields?[0] else { return }
                guard let text = textField.text, !text.isEmpty else { return }
                closure(text)
            }
            let cancel = UIAlertAction(title: "Cancel".localized, style: .cancel, handler: nil)
            temp.addAction(confirm)
            temp.addAction(cancel)
            self.present(temp, animated: true, completion: nil)
        }
    }
}

public class TSTableView: UITableView {
    
    /// 如果bk_placeholderView为空，将使用这个closure生成占位图
    public static var placeholderViewClosure: (() -> UIView)?
    
    /// 对象的独特占位图
    public var placeholderView: UIView?
    
    public override func removeFromSuperview() {
        removeObserver(self, forKeyPath: "contentSize")
        super.removeFromSuperview()
    }
    
    public override func willMove(toSuperview newSuperview: UIView?) {
        if newSuperview != nil {
            addObserver(self, forKeyPath: "contentSize", options: [.new], context: nil)
        }
        super.willMove(toSuperview: newSuperview)
    }
    
    public override func observeValue(forKeyPath keyPath: String?, of object: Any?, change: [NSKeyValueChangeKey : Any]?, context: UnsafeMutableRawPointer?) {
        if let keyPath = keyPath, keyPath == "contentSize" {
            for i in 0..<numberOfSections {
                if numberOfRows(inSection: i) != 0 {
                    backgroundView = nil
                    return
                }
            }
            if let background = self.placeholderView {
                backgroundView = background
            }else {
                backgroundView = TSTableView.placeholderViewClosure?()
            }
        }
    }
}




