//
//  PDBLEViewController.swift
//  PrinterDemo
//
//  Created by ios on 2019/9/9.
//  Copyright © 2019 XiamenHY. All rights reserved.
//

import UIKit

class PDBLEViewController: PDBaseViewController {
    
    private var dataSources = [HYPrinterMessage]()
    
    lazy var tableView : UITableView = {
        let temp = UITableView.init(frame: .zero, style: .grouped)
        temp.delegate = self
        temp.dataSource = self
        temp.backgroundColor = .white
        temp.rowHeight = 60.0
        temp.showsVerticalScrollIndicator = false
        temp.separatorStyle = UITableViewCell.SeparatorStyle.singleLine
        return temp
    }()
    
    lazy var mj_header: MJRefreshNormalHeader = {
        let temp = MJRefreshNormalHeader.init(refreshingTarget: self, refreshingAction: #selector(loadBLE))!
        temp.setTitle("Scanning nearby Bluetooth".localized, for: MJRefreshState.refreshing)
        temp.stateLabel.textColor = UIColor.gray
        temp.lastUpdatedTimeLabel.isHidden = true
        temp.activityIndicatorViewStyle = UIActivityIndicatorView.Style.gray
        return temp
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        navigationItem.title = "BLE".localized
        
        view.addSubview(tableView)
        tableView.snp.makeConstraints {
            $0.edges.equalTo(self.view.usnp.edges)
        }
        tableView.mj_header = mj_header
        HYPrinterInterface.shared()?.delegate = self
    }
    
    @objc func loadBLE() {
        if HYPrinterInterface.shared()?.hyGetBluetoothStatus() == HYBluetoothState.poweredOn {
            HYPrinterInterface.shared()?.hyStopScanBluetooth()
            dataSources.removeAll()
            self.tableView.reloadData()
            HYPrinterInterface.shared()?.hyScanBluetooth()
        }else if HYPrinterInterface.shared()?.hyGetBluetoothStatus() == HYBluetoothState.poweredOff {
            self.mj_header.endRefreshing()
            SVProgressHUD.showInfo(withStatus: "Please turn on Bluetooth".localized)
        }else {
            self.mj_header.endRefreshing()
            SVProgressHUD.showInfo(withStatus: "Please go to system Settings to find your APP open bluetooth permissions".localized)
        }
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        
        if HYPrinterInterface.shared()?.hyGetBluetoothStatus() == HYBluetoothState.poweredOn {
            HYPrinterInterface.shared()?.hyScanBluetooth()
        }else if HYPrinterInterface.shared()?.hyGetBluetoothStatus() == HYBluetoothState.poweredOff {
            SVProgressHUD.showInfo(withStatus: "Please turn on Bluetooth".localized)
        }else {
            SVProgressHUD.showInfo(withStatus: "Please go to system Settings to find your APP open bluetooth permissions".localized)
        }
    }
    
    override func viewWillDisappear(_ animated: Bool) {
        super.viewWillDisappear(animated)
        
    }
}

extension PDBLEViewController : HYPrinterInterfaceDelegate {
    
    func hyBleDidDiscoverPrints(_ devices: [HYPrinterMessage]!) {
        self.dataSources = devices.sorted(by: { return $0.distance.floatValue < $1.distance.floatValue })
        self.mj_header.endRefreshing()
        self.tableView.reloadData()
    }
    
    func hyDidConnectSuccess() {
        SVProgressHUD.showSuccess(withStatus: "Connection succeeded".localized)
        self.navigationController?.popToRootViewController(animated: true)
    }
    
    func hyDidConnectFail(_ error: Error!) {
        SVProgressHUD.showError(withStatus: error.localizedDescription)
    }
}

extension PDBLEViewController : UITableViewDelegate,UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return dataSources.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        var cell = tableView.dequeueReusableCell(withIdentifier: "iden")
        if cell == nil {
            cell = UITableViewCell.init(style: UITableViewCell.CellStyle.subtitle, reuseIdentifier: "iden")
        }
        cell?.textLabel?.text = dataSources[indexPath.row].name
        cell?.detailTextLabel?.text = dataSources[indexPath.row].mac
        
        cell?.textLabel?.textColor = UIColor.black
        cell?.detailTextLabel?.textColor = UIColor.titleColor
        
        return cell!
    }
    
    func tableView(_ tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
        return "Bluetooth device nearby".localized
    }
    
    func tableView(_ tableView: UITableView, heightForHeaderInSection section: Int) -> CGFloat {
        return 45.0
    }
    
    func tableView(_ tableView: UITableView, heightForFooterInSection section: Int) -> CGFloat {
        return 0.01
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        tableView.deselectRow(at: indexPath, animated: true)
        
        SVProgressHUD.show(withStatus: "Connecting, pls. wait".localized)
        HYPrinterInterface.shared()?.hyConnectPrinter(dataSources[indexPath.row])
    }
}
