//
//  PDConfigInfoViewController.swift
//  PrinterDemo
//
//  Created by ios on 2020/8/12.
//  Copyright © 2020 XiamenHY. All rights reserved.
//

import UIKit

enum TReuseIdentifier: String {
    case longDropTime
    case shortDropTime
    case shortDropIntv
    case shortDropNum
    case vibrationTime
    case tailed
    case convstr
    case volume
    case sleepTime
    case shutdownTime
    case scanMode
    case isVox
    case isVibrate
    case scanIntvTime
}

struct TBuildFunction {
    var title: String
    var param: TBuildParam
    var titleDesc: String
    var reuseIdentifier: TReuseIdentifier
    var segments: [String]
    
    enum TBuildParam {
        case textField
        case segment
    }
}

class PDConfigInfoViewController: PDBaseViewController {
    
    private lazy var tableView: UITableView = {
        let tw = UITableView(frame: CGRect.zero, style: .plain)
        tw.delegate = self
        tw.dataSource = self
        tw.backgroundColor = .white
        tw.showsVerticalScrollIndicator = false
        tw.separatorStyle = .none
        tw.isUserInteractionEnabled = true
        tw.keyboardDismissMode = .onDrag
        return tw
    }()
    
    private var functions = [TBuildFunction]()
    private var cells = [PDInfoTableViewCell]()
    private var infoModel = HYDeviceConfigInfo()
    
    override func viewDidLoad() {
        super.viewDidLoad()
    }
    
    override func configUI() {
        
        navigationItem.title = "Config Info".localized
        view.backgroundColor = TSColor.background
        navigationItem.rightBarButtonItem = UIBarButtonItem(title: "Config".localized, style: .plain, target: self, action: #selector(self.configDeviceInfo))
        
        view.addSubview(tableView)
        tableView.snp.makeConstraints {
            $0.edges.equalTo(self.view.usnp.edges)
        }
        loadLocalData()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        getConfigInfo()
    }
    
    private func loadLocalData() {
        
        var fuction: TBuildFunction
        fuction = TBuildFunction.init(title: "Long drop time(3-30)".localized, param: .textField, titleDesc: "", reuseIdentifier: TReuseIdentifier.longDropTime, segments: [])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "Short drop time(1-5)".localized, param: .textField, titleDesc: "", reuseIdentifier: TReuseIdentifier.shortDropTime, segments: [])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "Short drop interval(1-5)".localized, param: .textField, titleDesc: "", reuseIdentifier: TReuseIdentifier.shortDropIntv, segments: [])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "Short drop number(1-10)".localized, param: .textField, titleDesc: "", reuseIdentifier: TReuseIdentifier.shortDropNum, segments: [])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "Vibration time(3-30)".localized, param: .textField, titleDesc: "", reuseIdentifier: TReuseIdentifier.vibrationTime, segments: [])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "At the end of the enter".localized, param: .segment, titleDesc: "", reuseIdentifier: TReuseIdentifier.tailed, segments: ["Do not add enter".localized, "Add a carriage return".localized])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "Letter case conversion".localized, param: .segment, titleDesc: "", reuseIdentifier: TReuseIdentifier.convstr, segments: ["Remain unchanged".localized, "Lower case".localized, "Upper case".localized])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "Sound level(1-255)".localized, param: .textField, titleDesc: "", reuseIdentifier: TReuseIdentifier.volume, segments: [])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "Close the scan head time(3-60s)".localized, param: .textField, titleDesc: "", reuseIdentifier: TReuseIdentifier.sleepTime, segments: [])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "Device automatic shutdown time(3-60min)".localized, param: .textField, titleDesc: "", reuseIdentifier: TReuseIdentifier.shutdownTime, segments: [])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "Automatic continuous scanning mode".localized, param: .segment, titleDesc: "", reuseIdentifier: TReuseIdentifier.scanMode, segments: ["close".localized,"open".localized])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "Whether to turn on the sound".localized, param: .segment, titleDesc: "", reuseIdentifier: TReuseIdentifier.isVox, segments: ["close".localized,"open".localized])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "Whether to turn on the vibration".localized, param: .segment, titleDesc: "", reuseIdentifier: TReuseIdentifier.isVibrate, segments: ["close".localized,"open".localized])
        functions.append(fuction)
        
        fuction = TBuildFunction.init(title: "Continuous sweep interval(100-5000ms),This item requires firmware support".localized, param: .textField, titleDesc: "", reuseIdentifier: TReuseIdentifier.scanIntvTime, segments: [])
        functions.append(fuction)
    }
    
     /// 读取
    private func getConfigInfo() {
        let info = HYCmdGenerator.readDeviceConfigInfo()
        HYPrinterInterface.shared()?.sendData(toPeripheral: info)
        HYPrinterInterface.shared()?.hyReceiveDataCallBack({[weak self] (data) in
            guard let self = self else { return }
            guard let data = data else { return }
            if let model = HYCmdGenerator.resolveInfoData(data) {
                self.infoModel = model
            }
            self.tableView.reloadData()
        })
        HYPrinterInterface.shared()?.hySendDataFailCallBack({
            SVProgressHUD.showError(withStatus: "Data send failed".localized)
        })
        HYPrinterInterface.shared()?.hySendDataSuccessCallBack(nil)
        HYPrinterInterface.shared()?.hySendDataProgressCallBack(nil)
    }
    
    deinit {
        print("PDConfigInfoViewController---")
    }
}

extension PDConfigInfoViewController {
    
    /// 配置
    @objc func configDeviceInfo() {
        
        self.view.endEditing(true)
        
        if infoModel.longDropTime < 3 || infoModel.longDropTime > 30 {
            SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
            return
        }
        
        if infoModel.shortDropTime < 1 || infoModel.shortDropTime > 5 {
            SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
            return
        }
        
        if infoModel.shortDropIntv < 1 || infoModel.shortDropIntv > 5 {
            SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
            return
        }
        
        if infoModel.shortDropNum < 1 || infoModel.shortDropNum > 10 {
            SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
            return
        }
        
        if infoModel.vibrationTime < 3 || infoModel.vibrationTime > 30 {
            SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
            return
        }
        
        if infoModel.sleepTime < 3 || infoModel.sleepTime > 60 {
            SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
            return
        }
        
        if infoModel.shutdownTime < 3 || infoModel.shutdownTime > 60 {
            SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
            return
        }
        
        if infoModel.scanIntvTime < 100 || infoModel.scanIntvTime > 5000 {
            SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
            return
        }
        
        let data = HYCmdGenerator.configDeviceInfoModel(infoModel)
        HYPrinterInterface.shared()?.sendData(toPeripheral: data)
        HYPrinterInterface.shared()?.hyReceiveDataCallBack({[weak self] (data) in
            guard let self = self else { return }
            guard let data = data else { return }
            if let model = HYCmdGenerator.resolve(data) {
                if model.type == .setInfo {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.bk_presentWarningAlertController(title: "Setup succeeded".localized, message: "", style: .default)
                    }else {
                        self.bk_presentWarningAlertController(title: "Setup failed".localized, message: "", style: .default)
                    }
                }
            }
        })
        HYPrinterInterface.shared()?.hySendDataFailCallBack({
            SVProgressHUD.showError(withStatus: "Data send failed".localized)
        })
        HYPrinterInterface.shared()?.hySendDataSuccessCallBack(nil)
        HYPrinterInterface.shared()?.hySendDataProgressCallBack(nil)
    }
}

extension PDConfigInfoViewController : UITableViewDelegate, UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return functions.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        let fuction = functions[indexPath.row]
        var cell = cells.first(where: { $0.function as AnyObject === fuction as AnyObject})
        if cell == nil {
            cell = PDInfoTableViewCell.init(fuction)
            cells.append(cell!)
        }
        switch indexPath.row {
            case 0:
                cell?.markTF.text = "\(infoModel.longDropTime)"
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.longDropTime = $0
            }
            case 1:
                cell?.markTF.text = "\(infoModel.shortDropTime)"
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.shortDropTime = $0
            }
            case 2:
                cell?.markTF.text = "\(infoModel.shortDropIntv)"
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.shortDropIntv = $0
            }
            case 3:
                cell?.markTF.text = "\(infoModel.shortDropNum)"
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.shortDropNum = $0
            }
            case 4:
                cell?.markTF.text = "\(infoModel.vibrationTime)"
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.vibrationTime = $0
            }
            case 5:
                cell?.segmentControl.selectedSegmentIndex = infoModel.tailed
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.tailed = $0
            }
            case 6:
                cell?.segmentControl.selectedSegmentIndex = infoModel.convstr
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.convstr = $0
            }
            case 7:
                cell?.markTF.text = "\(infoModel.volume)"
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.volume = $0
            }
            case 8:
                cell?.markTF.text = "\(infoModel.sleepTime)"
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.sleepTime = $0
            }
            case 9:
                cell?.markTF.text = "\(infoModel.shutdownTime)"
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.shutdownTime = $0
            }
            case 10:
                cell?.segmentControl.selectedSegmentIndex = infoModel.scanMode
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.scanMode = $0
            }
            case 11:
                cell?.segmentControl.selectedSegmentIndex = infoModel.isVox ? 1 : 0
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.isVox = $0 > 0
            }
            case 12:
                cell?.segmentControl.selectedSegmentIndex = infoModel.isVibrate ? 1 : 0
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.isVibrate = $0 > 0
            }
            case 13:
                cell?.markTF.text = "\(infoModel.scanIntvTime)"
                cell?.didInputItemClosure = {[weak self] in
                    guard let self = self else { return }
                    self.infoModel.scanIntvTime = $0
            }
            default:
                break
        }
        return cell!
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        
        let titleH = functions[indexPath.row].title.drawHeight(with: kScreenWidth - 36, font: UIFont.pingFang(size: 14))
        return titleH + 70
    }
}
