//
//  PDDisplayDataViewController.swift
//  PrinterDemo
//
//  Created by ios on 2020/8/13.
//  Copyright © 2020 XiamenHY. All rights reserved.
//

import UIKit

class PDDisplayDataViewController: PDBaseViewController {

    override func viewDidLoad() {
        super.viewDidLoad()

    }

    override func configUI() {
        navigationItem.title = "Display scan data".localized
        
        view.addSubview(textView)
        textView.snp.makeConstraints {
            $0.width.equalTo(kScreenWidth - 40)
            $0.centerX.equalToSuperview()
            $0.top.equalTo(50)
            $0.height.equalTo(350)
        }
    }
    
    lazy var textView: UITextView = {
        return UITextView().then {
            $0.textColor = TSColor.title
            $0.font = UIFont.pingFang(size: 15)
            $0.layer.borderColor = TSColor.dividerLine.cgColor
            $0.layer.borderWidth = 0.5
            $0.layer.cornerRadius = 5
            $0.layer.shadowOffset = CGSize(width: 0, height: 0)
            $0.layer.shadowColor = TSColor.black.cgColor
            $0.layer.shadowOpacity = 0.1
            $0.layer.shadowRadius = 1
        }
    }()
    
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        
        let data = HYCmdGenerator.readDeviceTemporaryDataQuantity()
        HYPrinterInterface.shared()?.sendData(toPeripheral: data)
        HYPrinterInterface.shared()?.hyReceiveDataCallBack({[weak self] (data) in
            guard let self = self else { return }
            guard let data = data else { return }
            if let model = HYCmdGenerator.resolve(data) {
                switch model.type {
                    case .readTemporaryStatistical:
                        let state = model.content.read(to: UInt8.self, offset: 4)! > 0
                        if state {
                            self.bk_presentWarningAlertController(title: "Scan data will not be displayed when the temporary storage function is on. Only when the temporary storage function is off, can it be displayed".localized, message: "", style: .default)
                        }
                    case .readScanData:
                    guard let ctx = String.init(data: model.content[0..<model.content.endIndex], encoding: .ascii) else { return }
                    self.textView.text.append(ctx)
                    default:
                    break
                }
            }
        })
        HYPrinterInterface.shared()?.hySendDataFailCallBack({
            SVProgressHUD.showError(withStatus: "Data send failed".localized)
        })
        HYPrinterInterface.shared()?.hySendDataSuccessCallBack(nil)
        HYPrinterInterface.shared()?.hySendDataProgressCallBack(nil)
    }
}



