//
//  PDInfoTableViewCell.swift
//  PrinterDemo
//
//  Created by ios on 2020/8/12.
//  Copyright © 2020 XiamenHY. All rights reserved.
//

import UIKit

class PDInfoTableViewCell: UITableViewCell {
    
    var function: TBuildFunction
    
    var didInputItemClosure: ((_ item:Int) -> Void)?
    
    init(_ function: TBuildFunction) {
        self.function = function
        
        super.init(style: .default, reuseIdentifier: function.reuseIdentifier.rawValue)
        selectionStyle = .none
        backgroundColor = .white
        isUserInteractionEnabled = true
        configUI()
    }
    
    func configUI() {
        
        switch function.param {
            case .textField:
                addSubview(titleLb)
                titleLb.snp.makeConstraints {
                    $0.left.equalTo(18)
                    $0.top.equalTo(8)
                    $0.right.equalTo(-18)
                }
                addSubview(markTF)
                markTF.snp.makeConstraints {
                    $0.centerX.equalToSuperview()
                    $0.width.equalTo(200)
                    $0.top.equalTo(titleLb.snp.bottom).offset(10)
                    $0.height.equalTo(45)
                }
                addSubview(dividerView)
                dividerView.snp.makeConstraints {
                    $0.left.equalTo(15)
                    $0.right.equalTo(-15)
                    $0.bottom.equalTo(-0.5)
                    $0.height.equalTo(0.5)
            }
            case .segment:
                addSubview(titleLb)
                titleLb.snp.makeConstraints {
                    $0.left.equalTo(18)
                    $0.top.equalTo(8)
                    $0.right.equalTo(-18)
                }
                addSubview(segmentControl)
                segmentControl.snp.makeConstraints {
                    $0.centerX.equalToSuperview()
                    $0.width.equalTo(200)
                    $0.top.equalTo(titleLb.snp.bottom).offset(10)
                    $0.height.equalTo(45)
                }
                addSubview(dividerView)
                dividerView.snp.makeConstraints {
                    $0.left.equalTo(15)
                    $0.right.equalTo(-15)
                    $0.bottom.equalTo(-0.5)
                    $0.height.equalTo(0.5)
            }
        }
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    lazy var titleLb: UILabel = {
        return UILabel().then {
            $0.text = function.title
            $0.textColor = TSColor.title
            $0.font = UIFont.pingFang(size: 14)
            $0.numberOfLines = 0
        }
    }()
    
    lazy var markTF: UITextField = {
        let temp = UITextField()
        temp.delegate = self
        temp.textAlignment = .center
        temp.font = UIFont.pingFang(size: 16, traits: .medium)
        temp.textColor = TSColor.title
        temp.clearButtonMode = .whileEditing
        temp.keyboardType = .decimalPad
        temp.attributedPlaceholder = NSAttributedString(string: function.titleDesc, attributes: [NSAttributedString.Key.font:UIFont.pingFang(size: 14, traits: .regular)])
        temp.layer.borderColor = TSColor.dividerLine.cgColor
        temp.layer.borderWidth = 0.5
        temp.layer.cornerRadius = 4
        temp.layer.shadowOffset = CGSize(width: 0, height: 0)
        temp.layer.shadowColor = TSColor.black.cgColor
        temp.layer.shadowOpacity = 0.1
        temp.layer.shadowRadius = 1
        return temp
    }()
    
    lazy var segmentControl: UISegmentedControl = {
        let temp = UISegmentedControl.init(items: function.segments)
        if #available(iOS 13, *) {
            temp.selectedSegmentTintColor = UIColor.theme
        }else {
            temp.tintColor = UIColor.theme
        }
        temp.setTitleTextAttributes([NSAttributedString.Key.font:UIFont.pingFang(size: 14),NSAttributedString.Key.foregroundColor:UIColor.black], for: UIControl.State.normal)
        temp.setTitleTextAttributes([NSAttributedString.Key.font:UIFont.pingFang(size: 14),NSAttributedString.Key.foregroundColor:UIColor.white], for: UIControl.State.selected)
        temp.addTarget(self, action: #selector(self.changeIndex(_:)), for: .valueChanged)
        return temp
    }()
    
    lazy var dividerView: UIView = {
        return UIView().then({ $0.backgroundColor = TSColor.dividerLine})
    }()
}

extension PDInfoTableViewCell {
    
    @objc private func changeIndex(_ segment:UISegmentedControl) {
        guard let closure = didInputItemClosure else { return }
        closure(segment.selectedSegmentIndex)
    }
}

extension PDInfoTableViewCell : UITextFieldDelegate {
    
    func textFieldDidEndEditing(_ textField: UITextField) {
        guard let closure = didInputItemClosure else { return }
        guard let temp = textField.text else { return }
        guard let result = Int(temp) else { return }
        closure(result)
    }
}
