//
//  PDSampleViewController.swift
//  PrinterDemo
//
//  Created by ios on 2020/8/12.
//  Copyright © 2020 XiamenHY. All rights reserved.
//

import UIKit

public struct PDSettingCellItem {
    var title: String
    var detailTitle: String?
    weak var target: NSObject?
    var selector: Selector?
}

class PDSampleViewController: PDBaseViewController {

    lazy var tableView : UITableView = {
        let temp = UITableView.init(frame: .zero, style: .plain)
        temp.delegate = self
        temp.dataSource = self
        temp.backgroundColor = .white
        temp.rowHeight = 50.0
        temp.showsVerticalScrollIndicator = false
        temp.separatorStyle = UITableViewCell.SeparatorStyle.singleLine
        return temp
    }()
    
    private var actions = [PDSettingCellItem]()
    var info = [(key: String,value: String)]()
    
    override func viewDidLoad() {
        super.viewDidLoad()

    }
    
    override func configUI() {
        
        navigationItem.title = "Test example".localized
        view.backgroundColor = TSColor.background
        
        view.addSubview(tableView)
        tableView.snp.makeConstraints {
            $0.edges.equalTo(self.view.usnp.edges)
        }
        
        loadDataSource()
    }
    
    private func loadDataSource() {
        
        actions.removeAll()
        var action : PDSettingCellItem
        action = PDSettingCellItem.init(title: "Configure device parameters".localized, detailTitle: nil, target: self, selector: #selector(self.readConfigInfo))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Display scan data".localized, detailTitle: nil, target: self, selector: #selector(self.displayScanData))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Read device name".localized, detailTitle: nil, target: self, selector: #selector(self.readName))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Modify device name".localized, detailTitle: nil, target: self, selector: #selector(self.modifyDeviceName))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Read device battery".localized, detailTitle: nil, target: self, selector: #selector(self.readBattery))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Read device work mode".localized, detailTitle: nil, target: self, selector: #selector(self.readWorkMode))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Set device work mode".localized, detailTitle: nil, target: self, selector: #selector(self.setDeviceWorkMode))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Read device mac".localized, detailTitle: nil, target: self, selector: #selector(self.readDeviceMac))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Set light mode".localized, detailTitle: nil, target: self, selector: #selector(self.setLightMode))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Set voice mode".localized, detailTitle: nil, target: self, selector: #selector(self.setVoiceMode))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Set vibration time".localized, detailTitle: nil, target: self, selector: #selector(self.setVibrationTime))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Restore function settings".localized, detailTitle: nil, target: self, selector: #selector(self.resetFactory))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Control device shutdown".localized, detailTitle: nil, target: self, selector: #selector(self.controlShutdown))
        actions.append(action)
                
        action = PDSettingCellItem.init(title: "Read device test mode status".localized, detailTitle: nil, target: self, selector: #selector(self.readDeviceTestModeState))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Set device test mode status".localized, detailTitle: nil, target: self, selector: #selector(self.setDeviceTestModeState))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Read device vibration status".localized, detailTitle: nil, target: self, selector: #selector(self.readDeviceVibrationState))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Set device vibration status".localized, detailTitle: nil, target: self, selector: #selector(self.setDeviceVibrationState))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Configure the end carriage return".localized, detailTitle: nil, target: self, selector: #selector(self.setTailedEnter))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Set automatic scan mode status".localized, detailTitle: nil, target: self, selector: #selector(self.setAutomaticScanModeState))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Set automatic scan interval".localized, detailTitle: nil, target: self, selector: #selector(self.setAutomaticScanInterval))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Configure the sound state of the device".localized, detailTitle: nil, target: self, selector: #selector(self.setVoiceState))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Configure case and letter conversion".localized, detailTitle: nil, target: self, selector: #selector(self.setConversionMode))
        actions.append(action)
        
        //---------------
        action = PDSettingCellItem.init(title: "Temporary function switch".localized, detailTitle: nil, target: self, selector: #selector(self.setTemporarySwitch))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Count temporary data".localized, detailTitle: nil, target: self, selector: #selector(self.CountTemporaryData))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Delete temporary data".localized, detailTitle: nil, target: self, selector: #selector(self.deleteTemporaryData))
        actions.append(action)
        
        action = PDSettingCellItem.init(title: "Upload temporary data".localized, detailTitle: nil, target: self, selector: #selector(self.uploadTemporaryData))
        actions.append(action)
    }
    
    deinit {
        print("PDSampleViewController-----")
    }
}

extension PDSampleViewController : UITableViewDelegate,UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return actions.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        var cell = tableView.dequeueReusableCell(withIdentifier: "iden")
        if cell == nil {
            cell = UITableViewCell.init(style: UITableViewCell.CellStyle.subtitle, reuseIdentifier: "iden")
        }
        cell?.textLabel?.text = actions[indexPath.row].title
        cell?.textLabel?.textColor = UIColor.black
        
        return cell!
    }
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        tableView.deselectRow(at: indexPath, animated: true)
        
        let action = actions[indexPath.row]
        if let target = action.target {
            if let selector = action.selector {
                target.perform(selector)
            }
        }
    }
}

extension PDSampleViewController {
    
    @objc private func readConfigInfo() {
        self.navigationController?.pushViewController(PDConfigInfoViewController(), animated: true)
    }
    
    @objc private func readName() {
        let data = HYCmdGenerator.readDeviceName()
        request(data) { [weak self] in
            guard let self = self else { return }
            if let model = HYCmdGenerator.resolve($0), model.type == .readDeviceName {
                guard let name = String.init(data: model.content, encoding: .ascii) else { return }
                self.info.append(("Device name".localized,name))
                self.showInfo()
            }
        }
    }
    
    @objc private func readBattery() {
        let data = HYCmdGenerator.readDeviceBattery()
        request(data) { [weak self] in
            guard let self = self else { return }
            if let model = HYCmdGenerator.resolve($0), model.type == .readBattery {
                /// 电池电压2个字节 高位在前
                var batData = Data()
                batData.append(model.content[1])
                batData.append(model.content[0])
                let battery = batData.read(to: UInt16.self)!
                self.info.append(("Voltage".localized,"\(battery)"))
                self.info.append(("Electricity".localized,"\(model.content[2])"))
                self.showInfo()
            }
        }
    }
    
    @objc private func readWorkMode() {
        let data = HYCmdGenerator.readDeviceWorkingMode()
        request(data) { [weak self] in
            guard let self = self else { return }
            if let model = HYCmdGenerator.resolve($0), model.type == .readWorkMode {
                if model.content[0] == 1 {
                    self.info.append(("Work mode".localized,"GATT"))
                }else {
                    self.info.append(("Work mode".localized,"HID"))
                }
                self.showInfo()
            }
        }
    }
    
    @objc private func readDeviceMac() {
        let data = HYCmdGenerator.readDeviceMac()
        request(data) { [weak self] in
            guard let self = self else { return }
            if let model = HYCmdGenerator.resolve($0), model.type == .readMac {
                self.info.append(("Mac".localized,model.content.macString))
                self.showInfo()
            }
        }
    }
    
    @objc private func setLightMode() {
        presentSegmentAlertController(title: "Set light mode".localized, msg: "\n\n", items: ["On".localized, "Flashing".localized, "Off".localized]) { (mode) in
            let data = HYCmdGenerator.setDeviceLightWithMode(mode + 1)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setLight {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Set light mode".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Set light mode".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        }
    }
    
    @objc private func setVoiceMode() {
        
        let alertVC = UIAlertController(title: "Set voice mode".localized, message: "\n\n", preferredStyle: .alert)
        
        let segment = UISegmentedControl.init(items: ["Long beep".localized,"Short beep".localized])
        if #available(iOS 13, *) {
            segment.selectedSegmentTintColor = UIColor.theme
        }else {
            segment.tintColor = UIColor.theme
        }
        segment.setTitleTextAttributes([NSAttributedString.Key.font:UIFont.pingFang(size: 14),NSAttributedString.Key.foregroundColor:UIColor.black], for: UIControl.State.normal)
        segment.setTitleTextAttributes([NSAttributedString.Key.font:UIFont.pingFang(size: 14),NSAttributedString.Key.foregroundColor:UIColor.white], for: UIControl.State.selected)

        alertVC.view.addSubview(segment)
        segment.snp.makeConstraints {
            $0.top.equalTo(60)
            $0.left.equalTo(22)
            $0.right.equalTo(-22)
        }
        alertVC.addTextField {
            $0.placeholder = "Please input times (1-10)".localized
            $0.keyboardType = .numberPad
        }
        let action1 = UIAlertAction.init(title: "OK".localized, style: .default, handler: {[weak alertVC](_) in
            guard let textField = alertVC?.textFields?.first, let temp = textField.text else { return }
            guard let num = Int(temp) else { return }
            if num <= 0 || num > 10 {
                SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
                return
            }
            let data = HYCmdGenerator.setDeviceVoiceWithMode(segment.selectedSegmentIndex + 1, dropNumber: num)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setVoice {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Set voice mode".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Set voice mode".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        })
        let action2 = UIAlertAction.init(title: "Cancel".localized, style: .cancel, handler: nil)
        alertVC.addAction(action1)
        alertVC.addAction(action2)
        self.present(alertVC, animated: true, completion: nil)
    }
    
    @objc private func setVibrationTime() {
        presentInputAlertController(msg: "Set vibration time".localized, inputDesc: "Vibration time(3-30)".localized) { [weak self](time) in
            guard let self = self else { return }
            guard let vibrate = Int(time) else { return }
            if vibrate < 3 || vibrate > 30 {
                SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
                return
            }
            let data = HYCmdGenerator.setDeviceVibrationWithTime(vibrate)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setVibrationTime {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Set vibration time".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Set vibration time".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        }
    }
    
    @objc private func controlShutdown() {
        let data = HYCmdGenerator.setDeviceShutdown()
        request(data) {
            if let model = HYCmdGenerator.resolve($0), model.type == .setShutdown {
                if model.content[0] == 1 {
                    self.info.append(("Control device shutdown".localized,"Setup succeeded".localized))
                }
                self.showInfo()
            }
        }
    }
    
    @objc private func resetFactory() {
        let data = HYCmdGenerator.setDeviceToRestoreFactorySettings()
        request(data) {
            if let model = HYCmdGenerator.resolve($0), model.type == .resetFactory {
                if model.content[0] == 1 {
                    self.info.append(("Restore function settings".localized,"Setup succeeded".localized))
                }
                self.showInfo()
            }
        }
    }
    
    @objc private func setDeviceWorkMode() {
        presentSegmentAlertController(title: "Set device work mode".localized, msg: "\n\n", items: ["GATT","HID"]) { (mode) in
            let data = HYCmdGenerator.configDeviceWorkingMode(mode + 1)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setWorkMode {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Set device work mode".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Set device work mode".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        }
    }
    
    @objc private func readDeviceTestModeState() {
        let data = HYCmdGenerator.readDeviceTestMode()
        request(data) { [weak self] in
            guard let self = self else { return }
            if let model = HYCmdGenerator.resolve($0), model.type == .readTestMode {
                if model.content[0] == 1 {
                    self.info.append(("Test mode".localized,"open".localized))
                }else {
                    self.info.append(("Test mode".localized,"close".localized))
                }
                self.showInfo()
            }
        }
    }
    
    @objc private func setDeviceTestModeState() {
        
        presentSegmentAlertController(title: "Set device test mode status".localized, msg: "\n\n", items: ["close".localized,"open".localized]) { (mode) in
            let data = HYCmdGenerator.setDeviceTestMode(mode)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setTestMode {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Set device test mode status".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Set device test mode status".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        }
    }
    
    @objc private func setDeviceVibrationState() {
        presentSegmentAlertController(title: "Set device vibration status".localized, msg: "\n\n", items: ["close".localized,"open".localized]) { (mode) in
            let data = HYCmdGenerator.setDeviceVibrationWithState(mode)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setVibrationState {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Set device vibration status".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Set device vibration status".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        }
    }
    
    @objc private func readDeviceVibrationState() {
        let data = HYCmdGenerator.readDeviceVibrationMode()
        request(data) { [weak self] in
            guard let self = self else { return }
            if let model = HYCmdGenerator.resolve($0), model.type == .readVibrationState {
                if model.content[0] == 1 {
                    self.info.append(("Vibration mode".localized,"open".localized))
                }else {
                    self.info.append(("Vibration mode".localized,"close".localized))
                }
                self.showInfo()
            }
        }
    }
    
    @objc private func modifyDeviceName() {
        
        presentInputNameAlertController(msg: "Modify device name".localized, inputDesc: "Please enter the device name".localized) { (temp) in
            if !temp.isDeviceName {
                SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
                return
            }
            if temp.count > 12 {
                SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
                return
            }
            let data = HYCmdGenerator.resetDeviceName(temp)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setDeviceName {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Modify device name".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Modify device name".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        }
    }
    
    @objc private func setTailedEnter() {
        presentSegmentAlertController(title: "Configure the end carriage return".localized, msg: "\n\n", items: ["Do not add enter".localized,"Add a carriage return".localized]) { (mode) in
            let data = HYCmdGenerator.configDeviceTailed(mode)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setTailed {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Configure the end carriage return".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Configure the end carriage return".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        }
    }
    
    @objc private func setAutomaticScanModeState() {
        presentSegmentAlertController(title: "Set automatic scan mode status".localized, msg: "\n\n", items: ["close".localized,"open".localized]) { (mode) in
            let data = HYCmdGenerator.configDeviceAutomaticScanMode(mode)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setAutomacticScanMode {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Set automatic scan mode status".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Set automatic scan mode status".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        }
    }
    
    @objc private func setAutomaticScanInterval() {
        presentInputAlertController(msg: "Set automatic scan interval".localized, inputDesc: "Please enter the interval (100-5000)".localized) { (temp) in
            guard let interval = Int(temp) else { return }
            if interval < 100 || interval > 5000 {
                SVProgressHUD.showError(withStatus: "Incorrect input, please re-enter".localized)
                return
            }
            let data = HYCmdGenerator.configDeviceAutomaticScanInterval(interval)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setAutomacticScanInterval {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Set automatic scan interval".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Set automatic scan interval".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        }
    }
    
    @objc private func setVoiceState() {
        presentSegmentAlertController(title: "Configure the sound state of the device".localized, msg: "\n\n", items: ["close".localized,"open".localized]) { (mode) in
            let data = HYCmdGenerator.configDeviceVoice(withState: mode)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setVoiceState {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Configure the sound state of the device".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Configure the sound state of the device".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        }
    }
    
    @objc private func setConversionMode() {
        presentSegmentAlertController(title: "Configure case and letter conversion".localized, msg: "\n\n", items: ["Remain unchanged".localized, "Lower case".localized, "Upper case".localized]) { (mode) in
            let data = HYCmdGenerator.configDeviceConversion(withMode: mode)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setConvstr {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Configure case and letter conversion".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Configure case and letter conversion".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        }
    }
    
    @objc private func setTemporarySwitch() {
        presentSegmentAlertController(title: "Temporary function switch".localized, msg: "\n\n", items: ["close".localized, "open".localized]) { (mode) in
            let data = HYCmdGenerator.setDeviceTemporaryFunctionWithState(mode)
            self.request(data) { [weak self] in
                guard let self = self else { return }
                if let model = HYCmdGenerator.resolve($0), model.type == .setTemporaryState {
                    if model.content[0] == HYProtocolStatus.success.rawValue {
                        self.info.append(("Temporary function switch".localized,"Setup succeeded".localized))
                    }else {
                        self.info.append(("Temporary function switch".localized,"Setup failed".localized))
                    }
                    self.showInfo()
                }
            }
        }
    }
    
    @objc private func CountTemporaryData() {
        let data = HYCmdGenerator.readDeviceTemporaryDataQuantity()
        request(data) {
            if let model = HYCmdGenerator.resolve($0), model.type == .readTemporaryStatistical {
                
                var storageData = Data()
                storageData.append(model.content[1])
                storageData.append(model.content[0])
                let storage = storageData.read(to: UInt16.self)!
                self.info.append(("Number of stored bars".localized,"\(storage)"))
                var remainData = Data()
                remainData.append(model.content[3])
                remainData.append(model.content[2])
                let remain = remainData.read(to: UInt16.self)!
                self.info.append(("Number of remaining storage bars".localized,"\(remain)"))
                let state = model.content.read(to: UInt8.self, offset: 4)! > 0
                self.info.append(("Temporary status".localized,state ? "open".localized : "close".localized))
                self.showInfo()
            }
        }
    }
    
    @objc private func deleteTemporaryData() {
        let data = HYCmdGenerator.removeDeviceTemporaryData()
        request(data) {
            if let model = HYCmdGenerator.resolve($0), model.type == .deleteTemporaryData {
                if model.content[0] == HYProtocolStatus.success.rawValue {
                    self.info.append(("Delete temporary data".localized,"Delete succeeded".localized))
                }else {
                    self.info.append(("Delete temporary data".localized,"Delete failed".localized))
                }
                self.showInfo()
            }
        }
    }
    
    @objc private func uploadTemporaryData() {
        self.navigationController?.pushViewController(PDUploadTemporaryViewController(), animated: true)
    }
    
    @objc private func displayScanData() {
        self.navigationController?.pushViewController(PDDisplayDataViewController(), animated: true)
    }
}

extension PDSampleViewController {
    
    private func request(_ cmdData:Data, receiveClosure: ((Data) -> Void)? ) {
        
        SVProgressHUD.show()
        HYPrinterInterface.shared()?.sendData(toPeripheral: cmdData)
        HYPrinterInterface.shared()?.hySendDataSuccessCallBack({
            SVProgressHUD.dismiss()
        })
        HYPrinterInterface.shared()?.hySendDataFailCallBack({
            SVProgressHUD.showError(withStatus: "Data send failed".localized)
        })
        HYPrinterInterface.shared()?.hyReceiveDataCallBack({
            guard let data = $0 else { return }
            guard let closure = receiveClosure else { return }
            closure(data)
        })
        HYPrinterInterface.shared()?.hySendDataProgressCallBack(nil)
    }
    
    func showInfo() {
        if info.count > 0 {
            let message = info.map({ "\($0.key): \($0.value)" }).joined(separator: "\n")
            self.bk_presentWarningAlertController(title: "Receive message".localized, message: message, style: .default)
        }
        info = []
    }
}


