//
//  PDUploadTemporaryViewController.swift
//  PrinterDemo
//
//  Created by ios on 2020/8/13.
//  Copyright © 2020 XiamenHY. All rights reserved.
//

import UIKit

class PDUploadTemporaryViewController: PDBaseViewController {

    private lazy var tableView: UITableView = {
        let tw = UITableView(frame: CGRect.zero, style: .plain)
        tw.delegate = self
        tw.dataSource = self
        tw.rowHeight = 50
        tw.backgroundColor = TSColor.background
        tw.showsVerticalScrollIndicator = false
        tw.separatorStyle = .singleLineEtched
        return tw
    }()
    
    var dataSource = [String]()
    override func viewDidLoad() {
        super.viewDidLoad()

        view.backgroundColor = TSColor.background
        navigationItem.title = "Temporary data".localized
        navigationItem.rightBarButtonItem = UIBarButtonItem(title: "Upload", style: .plain, target: self, action: #selector(self.uploadData))
        
        view.addSubview(tableView)
        tableView.snp.makeConstraints {
            $0.width.equalTo(kScreenWidth - 36)
            $0.centerX.equalToSuperview()
            $0.top.equalToSuperview()
            $0.bottom.edges.equalToSuperview()
        }
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        
        
    }
    
    @objc private func uploadData() {
        self.dataSource.removeAll()
        let data = HYCmdGenerator.uploadDeviceTemporaryData(withStartNum: 0, totalNum: 255)
        HYPrinterInterface.shared()?.sendData(toPeripheral: data)
        HYPrinterInterface.shared()?.hyReceiveDataCallBack({[weak self] (data) in
            guard let self = self else { return }
            guard let data = data else { return }
            if let model = HYCmdGenerator.resolve(data),model.type == .uploadTemporaryData {
                guard let ctx = String.init(data: model.content[1..<model.content.endIndex], encoding: .ascii) else { return }
                self.dataSource.append(ctx)
                
                if model.content[0] == 0 {
                    SVProgressHUD.showSuccess(withStatus: "All data has been uploaded".localized)
                }
                self.tableView.reloadData()
            }
        })
        HYPrinterInterface.shared()?.hySendDataFailCallBack({
            SVProgressHUD.showError(withStatus: "Data send failed".localized)
        })
        HYPrinterInterface.shared()?.hySendDataSuccessCallBack(nil)
        HYPrinterInterface.shared()?.hySendDataProgressCallBack(nil)
    }
}

extension PDUploadTemporaryViewController : UITableViewDelegate,UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 1
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return dataSource.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        
        let identifier = "iden"
        var cell = tableView.dequeueReusableCell(withIdentifier: identifier)
        if cell == nil {
            cell = UITableViewCell.init(style: UITableViewCell.CellStyle.subtitle, reuseIdentifier: identifier)
        }
        cell?.selectionStyle = .none
        cell?.textLabel?.text = dataSource[indexPath.row]
        cell?.textLabel?.font = UIFont.pingFang(size: 14)
        
        return cell!
    }
    
    func tableView(_ tableView: UITableView, viewForHeaderInSection section: Int) -> UIView? {
        return nil
    }
    
    func tableView(_ tableView: UITableView, heightForHeaderInSection section: Int) -> CGFloat {
        return 10
    }
    
    func tableView(_ tableView: UITableView, viewForFooterInSection section: Int) -> UIView? {
        return nil
    }
    
    func tableView(_ tableView: UITableView, heightForFooterInSection section: Int) -> CGFloat {
        return 0.01
    }
}







