//
//  HYDataResolveModel.h
//  HYPrinterSDK
//
//  Created by ios on 2020/8/12.
//  Copyright © 2020 XiamenHY. All rights reserved.
//

#import <Foundation/Foundation.h>

typedef NS_ENUM(Byte, HYProtocolStatus) {
    //成功
    HYProtocolStatusSuccess = 0,
    //失败
    HYProtocolStatusFail
};

typedef NS_ENUM(uint8_t, PHYCmdType) {
    
    PHYCmdReadInfo = 0x81,                       //读取设备信息测试
    PHYCmdSetInfo = 0x82,                        //设备信息测试
    PHYCmdSetLight = 0x83,                       //指示灯测试
    PHYCmdSetVoice = 0x84,                       //蜂鸣器测试
    PHYCmdSetVibrationTime = 0x85,               //震动时长测试
    PHYCmdSetShutdown = 0x86,                    //设备关机测试
    PHYCmdResetFactory = 0x87,                   //恢复出厂设置
    PHYCmdReadMac = 0x88,                        //读取mac地址
    PHYCmdReadBattery = 0x89,                    //读取设备电量
    PHYCmdSetTemporaryState = 0x91,              //暂存开关
    PHYCmdReadTemporaryStatistical = 0x92,       //暂存数据统计
    PHYCmdDeleteTemporaryData = 0x93,            //删除暂存数据
    PHYCmdUploadTemporaryData = 0x94,            //上传暂存数据
    PHYCmdSetWorkMode = 0xB1,                    //设置工作模式
    PHYCmdReadWorkMode = 0xB2,
    PHYCmdSetTestMode = 0xB3,                    //设置测试模式
    PHYCmdReadTestMode = 0xB4,
    PHYCmdSetVibrationState = 0xB5,              //设置震动开关
    PHYCmdReadVibrationState = 0xB6,
    PHYCmdSetDeviceName = 0xB7,                  //设置设备名称
    PHYCmdReadDeviceName = 0xB8,
    PHYCmdSetTailed = 0xB9,                      //设置结尾回车
    PHYCmdSetAutomacticScanMode = 0xBA,          //设置自动连续扫描模式
    PHYCmdSetVoiceState = 0xBB,                  //设置声音开关
    PHYCmdSetConvstr = 0xBC,                     //设置字母大小写转换
    PHYCmdSetAutomacticScanInterval = 0xBD,      //设置自动连续间隔时间
    PHYCmdReadScanData = 0xC1,                   //显示扫描数据
};

NS_ASSUME_NONNULL_BEGIN

@interface HYDataResolveModel : NSObject

//指令标志
@property (nonatomic, assign) PHYCmdType type;
//有效数据内容
@property (nonatomic, strong) NSData *content;

@end

/// 配置信息模型
@interface HYDeviceConfigInfo : NSObject

@property (nonatomic, assign) NSInteger longDropTime;
@property (nonatomic, assign) NSInteger shortDropTime;
@property (nonatomic, assign) NSInteger shortDropIntv;
@property (nonatomic, assign) NSInteger shortDropNum;
@property (nonatomic, assign) NSInteger vibrationTime;
@property (nonatomic, assign) NSInteger tailed;
@property (nonatomic, assign) NSInteger convstr;
@property (nonatomic, assign) NSInteger volume;
@property (nonatomic, assign) NSInteger vibrationVol;
@property (nonatomic, assign) NSInteger sleepTime;
@property (nonatomic, assign) NSInteger shutdownTime;
@property (nonatomic, assign) NSInteger scanMode;
@property (nonatomic, assign) NSInteger scanIntvTime;
@property (nonatomic, assign) BOOL      isVox;
@property (nonatomic, assign) BOOL      isVibrate;

/// 初始化
/// @param longDropTime 长鸣时长,(3~30),单位0.1s,默认值:5
/// @param shortDropTime 短鸣时长,(1~5),单位0.1s,默认值:1
/// @param shortDropIntv 短鸣间隔时长,(1~5),单位0.1s,默认值:2
/// @param shortDropNum 短鸣次数,(1~10),默认值:1
/// @param vibrationTime 震动时长,(3~30),单位0.1s,默认值:5
/// @param tailed 结尾回车,0：不添加回车，1：添加回车 默认值：1
/// @param convstr 大小写字母转换,(0~2),0:所有字母保持原样,1:小写,2:大写,默认值:0
/// @param volume 声音大小,(1~255),默认值:50
/// @param vibrationVol 暂时保留,50
/// @param sleepTime 无按键关闭扫描头时间，取值范围 3-60 秒(默认值=10 秒)
/// @param shutdownTime 无按键自动关机时间，取值范围 3-60 分钟(默认值=10 分 钟)
/// @param scanMode 自动连续扫描模式, 0:关闭自动模式,1：开启，默认是开启
/// @param isVox 声音,默认开启
/// @param isVibrate 震动，默认是关闭
/// @param scanIntvTime 连续扫描间隔时间(100-5000),单位ms 默认500ms
- (instancetype)initWithLongDropTime:(NSInteger)longDropTime shortDropTime:(NSInteger)shortDropTime shortDropIntv:(NSInteger)shortDropIntv shortDropNum:(NSInteger)shortDropNum vibrationTime:(NSInteger)vibrationTime tailed:(NSInteger)tailed convstr:(NSInteger)convstr volume:(NSInteger)volume vibrationVol:(NSInteger)vibrationVol sleepTime:(NSInteger)sleepTime shutdownTime:(NSInteger)shutdownTime scanMode:(NSInteger)scanMode isVox:(BOOL)isVox isVibrate:(BOOL)isVibrate scanIntvTime:(NSInteger)scanIntvTime;

@end

NS_ASSUME_NONNULL_END
