//
//  HYCmdGenerator.h
//  HYPrinterSDK
//
//  Created by ios on 2020/7/28.
//  Copyright © 2020 XiamenHY. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "HYDataResolveModel.h"

NS_ASSUME_NONNULL_BEGIN

@interface HYCmdGenerator : NSObject

+ (HYDataResolveModel *_Nullable)resolveData:(NSData *)data;

+ (HYDeviceConfigInfo *_Nullable)resolveInfoData:(NSData *)data;

/// 读取设备配置信息
+ (NSData *)readDeviceConfigInfo;

/// 配置信息
/// @param info 信息模型
+ (NSData *)configDeviceInfoModel:(HYDeviceConfigInfo *)info;

/// 设置灯光模式
/// @param mode 1~3,1:长亮 2:闪烁 3:长灭
+ (NSData *)setDeviceLightWithMode:(NSInteger)mode;
                                
/// 设置声音模式
/// @param mode 1~2, 1:长滴    2:短滴
/// @param dropNumber 次数, 1~10
+ (NSData *)setDeviceVoiceWithMode:(NSInteger)mode dropNumber:(NSInteger)dropNumber;
                                  
/// 设置设备震动时长
/// @param time 震动时长,1~30,单位0.1s
+ (NSData *)setDeviceVibrationWithTime:(NSInteger)time;
                            
/// 设置设备关机
+ (NSData *)setDeviceShutdown;

/// 设置设备恢复出厂设置
+ (NSData *)setDeviceToRestoreFactorySettings;

/// 读取设备Mac
+ (NSData *)readDeviceMac;

/// 读取设备电量
+ (NSData *)readDeviceBattery;

/// 配置设备工作模式
/// @param mode 1:GATT透传 2:HID
+ (NSData *)configDeviceWorkingMode:(NSInteger)mode;

/// 读取设备工作模式
+ (NSData *)readDeviceWorkingMode;

/// 设置设备测试模式
/// @param mode 0:测试模式关闭,1:开启
+ (NSData *)setDeviceTestMode:(NSInteger)mode;

/// 读取设备测试模式
+ (NSData *)readDeviceTestMode;

/// 设置设备震动开关
/// @param state 0:关闭震动 1:开启震动
+ (NSData *)setDeviceVibrationWithState:(NSInteger)state;

/// 读取设备震动开关
+ (NSData *)readDeviceVibrationMode;

/// 修改设备名称
/// @param deviceName 设备名，长度12字节以内，且只能英文、数字或者空格,默认值:HPRT SCANER
+ (NSData *)resetDeviceName:(NSString *)deviceName;

/// 读取设备名称
+ (NSData *)readDeviceName;

/// 配置结尾回车
/// @param tailed 0：不添加回车  1：添加回车
+ (NSData *)configDeviceTailed:(NSInteger)tailed;

/// 配置自动连续扫描模式
/// @param mode 0:关闭自动连续扫描模式,1:开启自动扫描模式
+ (NSData *)configDeviceAutomaticScanMode:(NSInteger)mode;

/// 配置自动连续扫描间隔时间
/// @param interval 间隔时间 100-5000，单位ms
+ (NSData *)configDeviceAutomaticScanInterval:(NSInteger)interval;

/// 配置设备的声音状态
/// @param state 0:关闭声音 1:开启声音
+ (NSData *)configDeviceVoiceWithState:(NSInteger)state;

/// 配置大小写字母转换
/// @param mode 0:所有字母保持原样 1:小写  2:大写
+ (NSData *)configDeviceConversionWithMode:(NSInteger)mode;

/// 设置暂存功能开关
/// @param state 0:关闭暂存功能，启用实时上传, 1:开启暂存功能,默认值:0
+ (NSData *)setDeviceTemporaryFunctionWithState:(NSInteger)state;

/// 暂存数据统计
+ (NSData *)readDeviceTemporaryDataQuantity;

/// 清空暂存数据
+ (NSData *)removeDeviceTemporaryData;

/// 上传暂存数据
/// @param startNum 起始条数,表示从第几条开始读取
/// @param totalNum 读取的条数,1-254表示读取的条数，255表示读取的总条数
+ (NSData *)uploadDeviceTemporaryDataWithStartNum:(NSInteger)startNum totalNum:(NSInteger)totalNum;

@end

NS_ASSUME_NONNULL_END
